@@ -1,16 +1,17 @@
 """ test with the TimeGrouper / grouping with datetimes """
 
+from datetime import datetime
+
+import numpy as np
+from numpy import nan
 import pytest
 import pytz
 
-from datetime import datetime
-import numpy as np
-from numpy import nan
+from pandas.compat import StringIO
 
 import pandas as pd
-from pandas import (DataFrame, date_range, Index,
-                    Series, MultiIndex, Timestamp, DatetimeIndex)
-from pandas.compat import StringIO
+from pandas import DataFrame, Index, MultiIndex, Series, Timestamp, date_range
+from pandas.core.groupby.ops import BinGrouper
 from pandas.util import testing as tm
 from pandas.util.testing import assert_frame_equal, assert_series_equal
 
@@ -41,12 +42,11 @@ class TestGroupBy(object):
             df = df.set_index(['Date'])
 
             expected = DataFrame(
-                {'Quantity': np.nan},
-                index=date_range('20130901 13:00:00',
-                                 '20131205 13:00:00', freq='5D',
+                {'Quantity': 0},
+                index=date_range('20130901',
+                                 '20131205', freq='5D',
                                  name='Date', closed='left'))
-            expected.iloc[[0, 6, 18], 0] = np.array(
-                [24., 6., 9.], dtype='float64')
+            expected.iloc[[0, 6, 18], 0] = np.array([24, 6, 9], dtype='int64')
 
             result1 = df.resample('5D') .sum()
             assert_frame_equal(result1, expected)
@@ -58,11 +58,12 @@ class TestGroupBy(object):
             result3 = df.groupby(pd.Grouper(freq='5D')).sum()
             assert_frame_equal(result3, expected)
 
-    def test_groupby_with_timegrouper_methods(self):
+    @pytest.mark.parametrize("should_sort", [True, False])
+    def test_groupby_with_timegrouper_methods(self, should_sort):
         # GH 3881
         # make sure API of timegrouper conforms
 
-        df_original = pd.DataFrame({
+        df = pd.DataFrame({
             'Branch': 'A A A A A B'.split(),
             'Buyer': 'Carl Mark Carl Joe Joe Carl'.split(),
             'Quantity': [1, 3, 5, 8, 9, 3],
@@ -76,16 +77,17 @@ class TestGroupBy(object):
             ]
         })
 
-        df_sorted = df_original.sort_values(by='Quantity', ascending=False)
+        if should_sort:
+            df = df.sort_values(by='Quantity', ascending=False)
 
-        for df in [df_original, df_sorted]:
-            df = df.set_index('Date', drop=False)
-            g = df.groupby(pd.Grouper(freq='6M'))
-            assert g.group_keys
-            assert isinstance(g.grouper, pd.core.groupby.BinGrouper)
-            groups = g.groups
-            assert isinstance(groups, dict)
-            assert len(groups) == 3
+        df = df.set_index('Date', drop=False)
+        g = df.groupby(pd.Grouper(freq='6M'))
+        assert g.group_keys
+
+        assert isinstance(g.grouper, BinGrouper)
+        groups = g.groups
+        assert isinstance(groups, dict)
+        assert len(groups) == 3
 
     def test_timegrouper_with_reg_groups(self):
 
@@ -245,6 +247,8 @@ class TestGroupBy(object):
             result = df.groupby([pd.Grouper(freq='1M', key='Date')]).sum()
             assert_frame_equal(result, expected)
 
+    @pytest.mark.parametrize('freq', ['D', 'M', 'A', 'Q-APR'])
+    def test_timegrouper_with_reg_groups_freq(self, freq):
         # GH 6764 multiple grouping with/without sort
         df = DataFrame({
             'date': pd.to_datetime([
@@ -258,20 +262,24 @@ class TestGroupBy(object):
             'cost1': [12, 15, 10, 24, 39, 1, 0, 90, 45, 34, 1, 12]
         }).set_index('date')
 
-        for freq in ['D', 'M', 'A', 'Q-APR']:
-            expected = df.groupby('user_id')[
-                'whole_cost'].resample(
-                    freq).sum().dropna().reorder_levels(
-                        ['date', 'user_id']).sort_index().astype('int64')
-            expected.name = 'whole_cost'
+        expected = (
+            df.groupby('user_id')['whole_cost']
+              .resample(freq)
+              .sum(min_count=1)  # XXX
+              .dropna()
+              .reorder_levels(['date', 'user_id'])
+              .sort_index()
+              .astype('int64')
+        )
+        expected.name = 'whole_cost'
 
-            result1 = df.sort_index().groupby([pd.Grouper(freq=freq),
-                                               'user_id'])['whole_cost'].sum()
-            assert_series_equal(result1, expected)
+        result1 = df.sort_index().groupby([pd.Grouper(freq=freq),
+                                           'user_id'])['whole_cost'].sum()
+        assert_series_equal(result1, expected)
 
-            result2 = df.groupby([pd.Grouper(freq=freq), 'user_id'])[
-                'whole_cost'].sum()
-            assert_series_equal(result2, expected)
+        result2 = df.groupby([pd.Grouper(freq=freq), 'user_id'])[
+            'whole_cost'].sum()
+        assert_series_equal(result2, expected)
 
     def test_timegrouper_get_group(self):
         # GH 6914
@@ -366,9 +374,9 @@ class TestGroupBy(object):
                             expected.reset_index(drop=True))
 
     def test_groupby_groups_datetimeindex(self):
-        # #1430
+        # GH#1430
         periods = 1000
-        ind = DatetimeIndex(start='2012/1/1', freq='5min', periods=periods)
+        ind = pd.date_range(start='2012/1/1', freq='5min', periods=periods)
         df = DataFrame({'high': np.arange(periods),
                         'low': np.arange(periods)}, index=ind)
         grouped = df.groupby(lambda x: datetime(x.year, x.month, x.day))
@@ -377,7 +385,7 @@ class TestGroupBy(object):
         groups = grouped.groups
         assert isinstance(list(groups.keys())[0], datetime)
 
-        # GH 11442
+        # GH#11442
         index = pd.date_range('2015/01/01', periods=5, name='date')
         df = pd.DataFrame({'A': [5, 6, 7, 8, 9],
                            'B': [1, 2, 3, 4, 5]}, index=index)
